@@ -1,6 +1,6 @@
 package Calendar::Plugin::Renderer::SVG::Page;
 
-$Calendar::Plugin::Renderer::SVG::Page::VERSION   = '0.04';
+$Calendar::Plugin::Renderer::SVG::Page::VERSION   = '0.05';
 $Calendar::Plugin::Renderer::SVG::Page::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Calendar::Plugin::Renderer::SVG::Page - Interface to 'page' of calendar in SVG f
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
@@ -36,7 +36,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Calendar-Plugin-Renderer>
+L<https://github.com/manwar/Calendar-Plugin-Renderer>
 
 =head1 BUGS
 
